@@ -1,6 +1,5 @@
 ############################################################################
-#
-# gmExceptions - classes for exceptions gnumed modules may throw
+# gmExceptions - classes for exceptions GNUmed modules may throw
 # --------------------------------------------------------------------------
 #
 # @author: Dr. Horst Herb
@@ -39,14 +38,6 @@ class AccessDenied(Exception):
 		return txt
 
 #------------------------------------------------------------
-class DatabaseObjectInUseError(Exception):
-	def __init__(self, msg):
-		self.errmsg = msg
-
-	def __str__(self):
-		return self.errmsg
-
-
 class ConnectionError(Exception):
 	#raised whenever the database backend connection fails
 	def __init__(self, errmsg):
@@ -55,35 +46,6 @@ class ConnectionError(Exception):
 	def __str__(self):
 		return self.errmsg
 
-class ConfigError(Exception):
-	#raised whenever a configuration error occurs
-	def __init__(self, errmsg):
-		self.errmsg=errmsg
-
-	def __str__(self):
-		return self.errmsg
-
-
-
-class NoGuiError(Exception):
-	def __init__(self, errmsg):
-		self.errmsg=errmsg
-
-	def __str__(self):
-		return self.errmsg
-
-
-class PureVirtualFunction(Exception):
-	#raised whenever the database backend connection fails
-	def __init__(self, errmsg=None):
-		if errmsg is not None:
-			self.errmsg=errmsg
-		else:
-			self.errmsg="Attempt to call a pure virtual function!"
-
-	def __str__(self):
-		return self.errmsg
-
 #------------------------------------------------------------
 # constructor errors
 class ConstructorError(Exception):
@@ -107,17 +69,4 @@ class NoSuchBusinessObjectError(ConstructorError):
 	def __str__(self):
 		return self.errmsg
 
-#------------------------------------------------------------
-class InvalidInputError(Exception):
-	"""Raised by business layers when an attempt is made to input
-	invalid data"""
-	def __init__(self, errmsg = None):
-		if errmsg is None:
-			self.errmsg = "%s.__init__() failed" % self.__class__.__name__
-		else:
-			self.errmsg = errmsg
-
-	def __str__(self):
-		return self.errmsg
-
 #=====================================================================
