@@ -1,4 +1,7 @@
-"""GNUmed client internationalization/localization.
+
+from __future__ import print_function
+
+__doc__ = """GNUmed client internationalization/localization.
 
 All i18n/l10n issues should be handled through this modules.
 
@@ -53,8 +56,14 @@ __license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
 
 # stdlib
-import sys, os.path, os, re as regex, locale, gettext, logging, codecs
-
+import sys
+import os.path
+import os
+import locale
+import gettext
+import logging
+import codecs
+import re as regex
 
 _log = logging.getLogger('gm.i18n')
 
@@ -102,6 +111,7 @@ def __split_locale_into_levels():
 	system_locale_level['language'] = system_locale.split('_', 1)[0]
 
 	_log.debug('system locale levels: %s', system_locale_level)
+
 #---------------------------------------------------------------------------
 def __log_locale_settings(message=None):
 	_setlocale_categories = {}
@@ -122,12 +132,12 @@ def __log_locale_settings(message=None):
 		_log.debug(message)
 
 	_log.debug('current locale settings:')
-	_log.debug('locale.get_locale(): %s' % str(locale.getlocale()))
+	_log.debug('locale.getlocale(): %s' % str(locale.getlocale()))
 	for category in _getlocale_categories.keys():
-		_log.debug('locale.get_locale(%s): %s' % (category, locale.getlocale(_getlocale_categories[category])))
+		_log.debug('locale.getlocale(%s): %s' % (category, locale.getlocale(_getlocale_categories[category])))
 
 	for category in _setlocale_categories.keys():
-		_log.debug('(locale.set_locale(%s): %s)' % (category, locale.setlocale(_setlocale_categories[category])))
+		_log.debug('(locale.setlocale(%s): %s)' % (category, locale.setlocale(_setlocale_categories[category])))
 
 	try:
 		_log.debug('locale.getdefaultlocale() - default (user) locale: %s' % str(locale.getdefaultlocale()))
@@ -196,7 +206,9 @@ def __log_locale_settings(message=None):
 		_log.exception('this OS does not support nl_langinfo')
 
 	_log.debug('gmI18N.get_encoding(): %s', get_encoding())
+
 #---------------------------------------------------------------------------
+#def _translate_protected(term, strip_left=None, strip_right=None):
 def _translate_protected(term):
 	"""This wraps _().
 
@@ -211,24 +223,23 @@ def _translate_protected(term):
 		_log.error('translation: %s', translation)
 		return term
 
-	term_substitutes = _substitutes_regex.findall(term)
-	trans_substitutes = _substitutes_regex.findall(translation)
+	substitution_keys_in_original = set(_substitutes_regex.findall(term))
+	substitution_keys_in_translation = set(_substitutes_regex.findall(translation))
 
-	# different number of %(...)s substitutes ?
-	if len(term_substitutes) != len(trans_substitutes):
-		_log.error('count("%(...)s") mismatch, returning untranslated string')
+	if not substitution_keys_in_translation.issubset(substitution_keys_in_original):
+		_log.error('"%(...)s" keys in translation not a subset of keys in original, returning untranslated string')
 		_log.error('original   : %s', term)
 		_log.error('translation: %s', translation)
 		return term
 
-	# different %(...)s substitutes ?
-	if set(term_substitutes) != set(trans_substitutes):
-		_log.error('"%(...)s" name mismatch, returning untranslated string')
-		_log.error('original   : %s', term)
-		_log.error('translation: %s', translation)
-		return term
+#	if strip_left is not None:
+#		translation = translation.lstrip(strip_left)
+#
+#	if strip_right is not None:
+#		translation = translation.rstrip(strip_right)
 
 	return translation
+
 #---------------------------------------------------------------------------
 # external API
 #---------------------------------------------------------------------------
@@ -236,7 +247,6 @@ def activate_locale():
 	"""Get system locale from environment."""
 	global system_locale
 
-	# logging state of affairs
 	__log_locale_settings('unmodified startup locale settings (should be [C])')
 
 	# activate user-preferred locale
@@ -255,7 +265,6 @@ def activate_locale():
 	except:
 		_log.exception('error activating user-default locale')
 
-	# logging state of affairs
 	__log_locale_settings('locale settings after activating user-default locale')
 
 	# did we find any locale setting ? assume en_EN if not
@@ -269,6 +278,7 @@ def activate_locale():
 	__split_locale_into_levels()
 
 	return True
+
 #---------------------------------------------------------------------------
 def install_domain(domain=None, language=None, prefer_local_catalog=False):
 	"""Install a text domain suitable for the main script."""
@@ -283,52 +293,101 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 	# http://www.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap08.html
 	_log.debug('searching message catalog file for system locale [%s]' % system_locale)
 
+	_log.debug('checking process environment:')
 	for env_var in ['LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG']:
 		tmp = os.getenv(env_var)
 		if env_var is None:
-			_log.debug('${%s} not set' % env_var)
+			_log.debug(' ${%s} not set' % env_var)
 		else:
-			_log.debug('${%s} = [%s]' % (env_var, tmp))
+			_log.debug(' ${%s} = [%s]' % (env_var, tmp))
 
+	# language codes to try
+	lang_candidates = []
+	# first: explicit language or default system language
+	# language=None: unadulterated default language for user (locale.getlocale()[0] value)
+	# language != None: explicit language setting as passed in by the caller
+	lang_candidates.append(language)
 	if language is not None:
-		_log.info('explicit setting of ${LANG} requested: [%s]' % language)
-		_log.info('this will override the system locale language setting')
-		os.environ['LANG'] = language
+		_log.info('explicit request for target language [%s]' % language)
+		# next: try default language for user if explicit language fails
+		lang_candidates.append(None)
+
+	# next try locale.getlocale()[0], if different (this can be strange on, say, Windows: Hungarian_Hungary)
+	if locale.getlocale()[0] not in lang_candidates:
+		lang_candidates.append(locale.getlocale()[0])
+
+	# next try locale.get*default*locale()[0], if different
+	if locale.getdefaultlocale()[0] not in lang_candidates:
+		lang_candidates.append(locale.getdefaultlocale()[0])
+
+	_log.debug('languages to try for translation: %s (None: implicit system default)', lang_candidates)
+	initial_lang = os.getenv('LANG')
+	_log.info('initial ${LANG} setting: %s', initial_lang)
+
+	# loop over language candidates
+	for lang_candidate in lang_candidates:
+		# setup baseline
+		_log.debug('resetting ${LANG} to initial user default [%s]', initial_lang)
+		if initial_lang is None:
+			del os.environ['LANG']
+			lang2log = u'$LANG=<>'
+		else:
+			os.environ['LANG'] = initial_lang
+			lang2log = u'$LANG(default)=%s' % initial_lang
+		# setup candidate language
+		if lang_candidate is not None:
+			_log.info('explicitely overriding system locale language [%s] by setting ${LANG} to [%s]', initial_lang, lang_candidate)
+			os.environ['LANG'] = lang_candidate
+			lang2log = u'$LANG(explicit)=%s' % lang_candidate
+
+		if __install_domain(domain = domain, prefer_local_catalog = prefer_local_catalog, language = lang2log):
+			return True
+
+	# install a dummy translation class
+	_log.warning("falling back to NullTranslations() class")
+	# this shouldn't fail
+	dummy = gettext.NullTranslations()
+	dummy.install()
+	return True
+
+#---------------------------------------------------------------------------
+def __install_domain(domain, prefer_local_catalog, language=u'?'):
+	# <language> only used for logging
 
 	# search for message catalog
-	candidates = []
+	candidate_PO_dirs = []
 
 	# - locally
 	if prefer_local_catalog:
-		_log.debug('preferring local message catalog')
+		_log.debug('prioritizing local message catalog')
 		# - one level above path to binary
 		#    last resort for inferior operating systems such as DOS/Windows
 		#    strip one directory level
 		#    this is a rather neat trick :-)
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..', 'po'))
-		_log.debug('looking above binary install directory [%s]' % loc_dir)
-		candidates.append(loc_dir)
+		_log.debug('looking one level above binary install directory: %s', loc_dir)
+		candidate_PO_dirs.append(loc_dir)
 		# - in path to binary
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), 'po'))
-		_log.debug('looking in binary install directory [%s]' % loc_dir)
-		candidates.append(loc_dir)
+		_log.debug('looking in binary install directory: %s', loc_dir)
+		candidate_PO_dirs.append(loc_dir)
 
 	# - standard places
 	if os.name == 'posix':
 		_log.debug('system is POSIX, looking in standard locations (see Python Manual)')
 		# if this is reported to segfault/fail/except on some
 		# systems we may have to assume "sys.prefix/share/locale/"
-		candidates.append(gettext.bindtextdomain(domain))
+		candidate_PO_dirs.append(gettext.bindtextdomain(domain))
 	else:
 		_log.debug('No use looking in standard POSIX locations - not a POSIX system.')
 
 	# - $(<script-name>_DIR)/
 	env_key = "%s_DIR" % os.path.splitext(os.path.basename(sys.argv[0]))[0].upper()
 	_log.debug('looking at ${%s}' % env_key)
-	if os.environ.has_key(env_key):
+	if env_key in os.environ:
 		loc_dir = os.path.abspath(os.path.join(os.environ[env_key], 'po'))
 		_log.debug('${%s} = "%s" -> [%s]' % (env_key, os.environ[env_key], loc_dir))
-		candidates.append(loc_dir)
+		candidate_PO_dirs.append(loc_dir)
 	else:
 		_log.info("${%s} not set" % env_key)
 
@@ -340,21 +399,22 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 		#    this is a rather neat trick :-)
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..', 'po'))
 		_log.debug('looking above binary install directory [%s]' % loc_dir)
-		candidates.append(loc_dir)
+		candidate_PO_dirs.append(loc_dir)
 		# - in path to binary
 		loc_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), 'po' ))
 		_log.debug('looking in binary install directory [%s]' % loc_dir)
-		candidates.append(loc_dir)
+		candidate_PO_dirs.append(loc_dir)
 
 	# now try to actually install it
-	for candidate in candidates:
-		_log.debug('trying [%s](/%s/LC_MESSAGES/%s.mo)', candidate, system_locale, domain)
-		if not os.path.exists(candidate):
+	for candidate_PO_dir in candidate_PO_dirs:
+		_log.debug('trying with (base=%s, %s, domain=%s)', candidate_PO_dir, language, domain)
+		_log.debug(' -> %s.mo', os.path.join(candidate_PO_dir, language, domain))
+		if not os.path.exists(candidate_PO_dir):
 			continue
 		try:
-			gettext.install(domain, candidate, unicode=1)
+			gettext.install(domain, candidate_PO_dir, unicode = 1)
 		except:
-			_log.exception('installing text domain [%s] failed from [%s]', domain, candidate)
+			_log.exception('installing text domain [%s] failed from [%s]', domain, candidate_PO_dir)
 			continue
 		global _
 		# does it translate ?
@@ -369,12 +429,8 @@ def install_domain(domain=None, language=None, prefer_local_catalog=False):
 			__builtin__._ = _translate_protected
 			return True
 
-	# 5) install a dummy translation class
-	_log.warning("falling back to NullTranslations() class")
-	# this shouldn't fail
-	dummy = gettext.NullTranslations()
-	dummy.install()
-	return True
+	return False
+
 #===========================================================================
 _encoding_mismatch_already_logged = False
 _current_encoding = None
@@ -419,6 +475,7 @@ def get_encoding():
 		_encoding_mismatch_already_logged = True
 
 	return locale.getpreferredencoding(do_setlocale=False)
+
 #===========================================================================
 # Main
 #---------------------------------------------------------------------------
@@ -451,22 +508,22 @@ if __name__ == "__main__":
 
 		]
 		for cands in candidates:
-			print cands[0], u'<vs>', cands[1], '=', locale.strcoll(cands[0], cands[1])
-#			print cands[1], u'<vs>', cands[0], '=', locale.strcoll(cands[1], cands[0])
+			print(cands[0], u'<vs>', cands[1], '=', locale.strcoll(cands[0], cands[1]))
+#			print(cands[1], u'<vs>', cands[0], '=', locale.strcoll(cands[1], cands[0]))
 
 	#----------------------------------------------------------------------
-	print "======================================================================"
-	print "GNUmed i18n"
-	print ""
-	print "authors:", __author__
-	print "license:", __license__
-	print "======================================================================"
+	print("======================================================================")
+	print("GNUmed i18n")
+	print("")
+	print("authors:", __author__)
+	print("license:", __license__)
+	print("======================================================================")
 
 	activate_locale()
-	print "system locale: ", system_locale, "; levels:", system_locale_level
-	print "likely encoding:", get_encoding()
+	print("system locale: ", system_locale, "; levels:", system_locale_level)
+	print("likely encoding:", get_encoding())
 
-	if len(sys.argv) > 1:
+	if len(sys.argv) > 2:
 		install_domain(domain = sys.argv[2])
 	else:
 		install_domain()
@@ -481,6 +538,3 @@ if __name__ == "__main__":
 	tmp = _('Translate this or i18n into <en_EN> will not work properly !') #
 	# ********************************************************************* #
 	# ********************************************************************* #
-
-#=====================================================================
-
