@@ -25,18 +25,21 @@ if __name__ == '__main__':
 import gmShellAPI
 import gmTools
 import gmCfg2
+import gmWorkerThread
 
 
 _log = logging.getLogger('gm.docs')
 
 #=======================================================================================
-def guess_mimetype(filename = None):
+def guess_mimetype(filename=None):
 	"""Guess mime type of arbitrary file.
 
 	filenames are supposed to be in Unicode
 	"""
 	worst_case = "application/octet-stream"
 
+	_log.debug('guessing mime type of [%s]', filename)
+
 	# 1) use Python libextractor
 	try:
 		import extractor
@@ -165,6 +168,7 @@ def guess_ext_by_mimetype(mimetype=''):
 	_log.error("<%s>: no suitable file extension found in config files" % mimetype)
 
 	return ext
+
 #-----------------------------------------------------------------------------------
 def guess_ext_for_file(aFile=None):
 	if aFile is None:
@@ -183,6 +187,26 @@ def guess_ext_for_file(aFile=None):
 
 	return f_ext
 
+#-----------------------------------------------------------------------------------
+def adjust_extension_by_mimetype(filename):
+	mimetype = guess_mimetype(filename)
+	mime_suffix = guess_ext_by_mimetype(mimetype)
+	if mime_suffix is None:
+		return filename
+	old_name, old_ext = os.path.splitext(filename)
+	if old_ext == u'':
+		new_filename = filename + mime_suffix
+	elif old_ext.lower() == mime_suffix.lower():
+		return filename
+	new_filename = old_name + mime_suffix
+	_log.debug(u'[%s] -> [%s]', filename, new_filename)
+	try:
+		os.rename(filename, new_filename)
+		return new_filename
+	except OSError:
+		_log.exception(u'cannot rename, returning original filename')
+	return filename
+
 #-----------------------------------------------------------------------------------
 _system_startfile_cmd = None
 
@@ -227,6 +251,12 @@ def convert_file(filename=None, target_mime=None, target_filename=None, target_e
 
 		target_mime: a mime type
 	"""
+	source_mime = guess_mimetype(filename = filename)
+	if source_mime.lower() == target_mime.lower():
+		_log.debug(u'source file [%s] already target mime type [%s]', filename, target_mime)
+		shutil.copyfile(filename, target_filename)
+		return True
+
 	if target_extension is None:
 		tmp, target_extension = os.path.splitext(target_filename)
 
@@ -261,7 +291,7 @@ def convert_file(filename=None, target_mime=None, target_filename=None, target_e
 	return True
 
 #-----------------------------------------------------------------------------------
-def describe_file(filename):
+def __run_file_describer(filename=None):
 
 	base_name = u'gm-describe_file'
 
@@ -304,6 +334,18 @@ def describe_file(filename):
 	desc_file.close()
 	return (True, desc)
 
+#-----------------------------------------------------------------------------------
+def describe_file(filename, callback=None):
+	if callback is None:
+		return __run_file_describer(filename)
+
+	payload_kwargs = {'filename': filename}
+	gmWorkerThread.execute_in_worker_thread (
+		payload_function = __run_file_describer,
+		payload_kwargs = payload_kwargs,
+		completion_callback = callback
+	)
+
 #-----------------------------------------------------------------------------------
 def call_viewer_on_file(aFile = None, block=None):
 	"""Try to find an appropriate viewer with all tricks and call it.
@@ -390,11 +432,16 @@ if __name__ == "__main__":
 
 	#_get_system_startfile_cmd(filename)
 	#print(_system_startfile_cmd)
-	print(guess_mimetype(filename))
+	#print(guess_mimetype(filename))
 	#print(get_viewer_cmd(guess_mimetype(filename), filename))
+	print(get_editor_cmd(guess_mimetype(filename), filename))
+	print(get_editor_cmd('application/x-latex', filename))
+	print(get_editor_cmd('application/x-tex', filename))
+	print(get_editor_cmd('text/latex', filename))
+	print(get_editor_cmd('text/tex', filename))
+	print(get_editor_cmd('text/plain', filename))
 	#print(guess_ext_by_mimetype(mimetype=filename))
 	#call_viewer_on_file(aFile = filename, block=None)
-
 	#status, desc = describe_file(filename)
 	#print status
 	#print desc
