@@ -17,19 +17,21 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.7.8 (database v22.8)',
-	'GNUmed 1.7.8 Release Notes:
+	'Release Notes for GNUmed 1.7.9 (database v22.9)',
+	'GNUmed 1.7.9 Release Notes:
 
-	1.7.8
+	1.7.9
 
-FIX: billing: invoice ID template configuration [thanks Marc]
-FIX: config: top pane lab panel setting [thanks Jelle Mous]
-FIX: searching across active EMR [thanks Eberhard]
+FIX: billing: invoice ID generation [thanks Marc]
+FIX: dist: GNUmed Manual d/l URL
+FIX: template: letter w/ & w/o Dx-s
+FIX: paperwork: letter receiver dlg address selection
+FIX: EMR/tree: exception on loading visual progress notes
 
-	22.8
+	22.9
 
-FIX: i18n.set_curr/force_curr_lang()
+FIX: clin.v_candidate_diagnoses: missing coalesce()
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.8');
+select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.9');
